@@ -30,7 +30,6 @@
 
 #include <gdk/gdkscreen.h>
 #include <gdk/gdkx.h>
-#include <glade/glade.h>
 #include <libgnomeui/gnome-help.h>
 
 #define GROUPS_SUBMENU_PATH "/popups/popup/groups"
@@ -146,44 +145,23 @@ GSwitchItAppletChangeOrient (PanelApplet * widget,
 }
 
 static void
-GSwitchItAppletSetBackground (PanelAppletBackgroundType type,
-			      GtkRcStyle * rc_style,
-			      GtkWidget * w,
-			      GdkColor * color, GdkPixmap * pixmap)
+GSwitchItAppletSetBackground (PanelApplet * applet, GtkWidget * w)
 {
-	GtkStyle *style;
+	panel_applet_set_background_widget (applet, w);
 
-	gtk_widget_set_style (GTK_WIDGET (w), NULL);
-	gtk_widget_modify_style (GTK_WIDGET (w), rc_style);
-
-	switch (type) {
-	case PANEL_NO_BACKGROUND:
-		break;
-	case PANEL_COLOR_BACKGROUND:
-		gtk_widget_modify_bg (GTK_WIDGET (w),
-				      GTK_STATE_NORMAL, color);
-		break;
-	case PANEL_PIXMAP_BACKGROUND:
-		style = gtk_style_copy (w->style);
-		if (style->bg_pixmap[GTK_STATE_NORMAL])
-			g_object_unref (style->
-					bg_pixmap[GTK_STATE_NORMAL]);
-		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
-		gtk_widget_set_style (w, style);
-		g_object_unref (style);
-		break;
-	}
 	/* go down */
 	if (GTK_IS_CONTAINER (w)) {
-		GList *child =
+                GList *child;
+		GList *children =
 		    gtk_container_get_children (GTK_CONTAINER (w));
+		child = children;
 		while (child != NULL) {
-			GSwitchItAppletSetBackground (type, rc_style,
+			GSwitchItAppletSetBackground (applet,
 						      GTK_WIDGET (child->
-								  data),
-						      color, pixmap);
+								  data));
 			child = child->next;
 		}
+		g_list_free (children);
 	}
 }
 
@@ -193,10 +171,8 @@ GSwitchItAppletChangeBackground (GtkWidget * widget,
 				 GdkColor * color, GdkPixmap * pixmap,
 				 GSwitchItApplet * sia)
 {
-	GtkRcStyle *rc_style = gtk_rc_style_new ();
-	GSwitchItAppletSetBackground (type, rc_style, widget, color,
-				      pixmap);
-	gtk_rc_style_unref (rc_style);
+		
+	GSwitchItAppletSetBackground (PANEL_APPLET (sia->applet), widget);
 }
 
 void
@@ -268,10 +244,10 @@ GSwitchItPreviewResponse (GtkWidget * dialog, gint resp)
 static void
 GSwitchItPreviewDestroy (GtkWidget * dialog, gint group)
 {
-	GladeXML *gladeData =
-	    GLADE_XML (gtk_object_get_data
-		       (GTK_OBJECT (dialog), "gladeData"));
-	g_object_unref (G_OBJECT (gladeData));
+	GtkBuilder *builder =
+	    GTK_BUILDER (gtk_object_get_data
+			 (GTK_OBJECT (dialog), "builderData"));
+	g_object_unref (G_OBJECT (builder));
 	g_hash_table_remove (globals.previewDialogs,
 			     GINT_TO_POINTER (group));
 }
@@ -293,11 +269,12 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 		groupsLevels + 3
 	};
 #ifdef HAVE_XKB
-	GladeXML *gladeData;
+	GtkBuilder *builder;
 	GtkWidget *dialog, *kbdraw;
 	XkbComponentNamesRec componentNames;
 	XklConfigRec *xklData;
 	GdkRectangle *rect;
+	GError *error = NULL;
 #endif
 	XklEngine *engine = gkbd_indicator_get_xkl_engine ();
 	XklState *xklState = xkl_engine_get_current_state (engine);
@@ -311,10 +288,20 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 		return;
 	}
 #ifdef HAVE_XKB
-	gladeData =
-	    glade_xml_new (GNOME_GLADEDIR "/gswitchit.glade",
-			   "gswitchit_layout_view", NULL);
-	dialog = glade_xml_get_widget (gladeData, "gswitchit_layout_view");
+	builder = gtk_builder_new ();
+	gtk_builder_add_from_file (builder, GTK_BUILDERDIR "/gswitchit.ui",
+				   &error);
+
+	if (error) {
+		g_error ("building ui from %s failed: %s",
+			 GTK_BUILDERDIR "/gswitchit.ui", error->message);
+		g_clear_error (&error);
+	}
+
+
+	dialog =
+	    GTK_WIDGET (gtk_builder_get_object
+			(builder, "gswitchit_layout_view"));
 	kbdraw = gkbd_keyboard_drawing_new ();
 
 	if (xklState->group >= 0 &&
@@ -377,7 +364,7 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 	}
 	g_object_unref (G_OBJECT (xklData));
 
-	gtk_object_set_data (GTK_OBJECT (dialog), "gladeData", gladeData);
+	gtk_object_set_data (GTK_OBJECT (dialog), "builderData", builder);
 	g_signal_connect (GTK_OBJECT (dialog),
 			  "destroy", G_CALLBACK (GSwitchItPreviewDestroy),
 			  GINT_TO_POINTER (xklState->group));
@@ -396,8 +383,8 @@ GSwitchItAppletCmdPreview (BonoboUIComponent *
 	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
 
 	gtk_container_add (GTK_CONTAINER
-			   (glade_xml_get_widget
-			    (gladeData, "preview_vbox")), kbdraw);
+			   (gtk_builder_get_object
+			    (builder, "preview_vbox")), kbdraw);
 
 	gtk_object_set_data (GTK_OBJECT (dialog), "kbdraw", kbdraw);
 
@@ -468,10 +455,10 @@ GSwitchItAppletCmdAbout (BonoboUIComponent *
 			 uic, GSwitchItApplet * sia, const gchar * verb)
 {
 	const gchar *authors[] = {
-		"Sergey V. Udaltsov<svu@gnome.org>", NULL
+		"Sergey V. Udaltsov <svu@gnome.org>", NULL
 	};
 	const gchar *documenters[] = {
-		"Sergey V. Udaltsov<svu@gnome.org>", NULL
+		"Sergey V. Udaltsov <svu@gnome.org>", NULL
 	};
 
 	const gchar *translator_credits = _("translator-credits");
@@ -489,7 +476,7 @@ GSwitchItAppletCmdAbout (BonoboUIComponent *
 			       strcmp (translator_credits,
 				       "translator-credits") !=
 			       0 ? translator_credits : NULL,
-			       "logo-icon-name", "gswitchit-applet", NULL);
+			       "logo-icon-name", "input-keyboard", NULL);
 }
 
 static void
@@ -572,9 +559,9 @@ GSwitchItAppletSetupMenu (GSwitchItApplet * sia)
 	/* Layout preview is for XKB only */
 	bonobo_ui_component_set_prop (popup, "/commands/Preview",
 				      "sensitive",
-				      g_strcasecmp ("XKB",
-						    engine_backend_name) ?
-				      "0" : "1", NULL);
+				      g_ascii_strcasecmp ("XKB",
+							  engine_backend_name)
+				      ? "0" : "1", NULL);
 
 	/* Delete the plugins item if the binary does not exist */
 	if (pluginsCappletFullPath == NULL)
@@ -600,12 +587,16 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 
 	g_set_application_name (_("Keyboard Indicator"));
 
-	gtk_window_set_default_icon_name ("gswitchit-applet");
+	gtk_window_set_default_icon_name ("input-keyboard");
 
 	sia->applet = GTK_WIDGET (applet);
 
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
+	/* enable transparency hack */
+	panel_applet_set_background_widget (PANEL_APPLET (applet),
+					    GTK_WIDGET (applet));
+
 	sia->gki = gkbd_indicator_new ();
 
 	orient = panel_applet_get_orient (applet);
